==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkMergeDataObjectFilter.java <==
// java wrapper for vtkMergeDataObjectFilter object
//

package vtk;
import vtk.*;

public class vtkMergeDataObjectFilter extends vtkDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDataObjectInputData_2(vtkDataObject id0);
  public void SetDataObjectInputData(vtkDataObject id0)
    { SetDataObjectInputData_2(id0); }

  private native long GetDataObject_3();
  public vtkDataObject GetDataObject() {
    long temp = GetDataObject_3();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutputField_4(int id0);
  public void SetOutputField(int id0)
    { SetOutputField_4(id0); }

  private native int GetOutputField_5();
  public int GetOutputField()
    { return GetOutputField_5(); }

  private native void SetOutputFieldToDataObjectField_6();
  public void SetOutputFieldToDataObjectField()
    { SetOutputFieldToDataObjectField_6(); }

  private native void SetOutputFieldToPointDataField_7();
  public void SetOutputFieldToPointDataField()
    { SetOutputFieldToPointDataField_7(); }

  private native void SetOutputFieldToCellDataField_8();
  public void SetOutputFieldToCellDataField()
    { SetOutputFieldToCellDataField_8(); }

  public vtkMergeDataObjectFilter() { super(); }

  public vtkMergeDataObjectFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv7h.pkg.tar.xz: vtk/vtkMergeDataObjectFilter.java <==
// java wrapper for vtkMergeDataObjectFilter object
//

package vtk;
import vtk.*;

public class vtkMergeDataObjectFilter extends vtkDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDataObjectInputData_2(vtkDataObject id0);
  public void SetDataObjectInputData(vtkDataObject id0)
    { SetDataObjectInputData_2(id0); }

  private native long GetDataObject_3();
  public vtkDataObject GetDataObject() {
    long temp = GetDataObject_3();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutputField_4(int id0);
  public void SetOutputField(int id0)
    { SetOutputField_4(id0); }

  private native int GetOutputField_5();
  public int GetOutputField()
    { return GetOutputField_5(); }

  private native void SetOutputFieldToDataObjectField_6();
  public void SetOutputFieldToDataObjectField()
    { SetOutputFieldToDataObjectField_6(); }

  private native void SetOutputFieldToPointDataField_7();
  public void SetOutputFieldToPointDataField()
    { SetOutputFieldToPointDataField_7(); }

  private native void SetOutputFieldToCellDataField_8();
  public void SetOutputFieldToCellDataField()
    { SetOutputFieldToCellDataField_8(); }

  public vtkMergeDataObjectFilter() { super(); }

  public vtkMergeDataObjectFilter(long id) { super(id); }
  public native long   VTKInit();

}
